@@ -6,11 +6,9 @@ Tests for `toolbox_utils` module.
 """
 
 import datetime
-from io import BytesIO, StringIO
 
 import pandas as pd
 import pytest
-from pandas.testing import assert_frame_equal
 
 from toolbox_utils import tsutils
 
@@ -39,6 +37,5 @@ def test_parsedate(test_input, strftime, expected):
     ],
 )
 def test_parsedate_exceptions(test_input, strftime, expected):
-    with pytest.raises(Exception) as excinfo:
-        ret = tsutils.parsedate(test_input, strftime=strftime)
-        print(ret)
+    with pytest.raises(Exception):
+        _ = tsutils.parsedate(test_input, strftime=strftime)
