@@ -5,10 +5,7 @@ catalog
 Tests for `hspf_reader hbn` module.
 """
 
-import shlex
-import subprocess
-import sys
-from io import BytesIO, StringIO
+from io import BytesIO
 from unittest import TestCase
 
 import pandas as pd
@@ -17,17 +14,6 @@ from pandas.testing import assert_frame_equal
 from toolbox_utils import tsutils
 
 
-def capture(func, *args, **kwds):
-    sys.stdout = StringIO()  # capture output
-    out = func(*args, **kwds)
-    out = sys.stdout.getvalue()  # release output
-    try:
-        out = bytes(out, "utf-8")
-    except:
-        pass
-    return out
-
-
 class TestDescribe(TestCase):
     def setUp(self):
         self.extract = b"""Datetime,PERLND_905_AGWS
